pub struct AudioTrack {
pub src: String,
pub start_from: f64,
pub timeline_start: f64,
pub duration: Option<f64>,
pub volume: f64,
pub playback_rate: f64,
pub looped: bool,
}Expand description
Audio source mixed into the encoded output.
Fields
src: StringLocal audio or video file containing an audio stream.
start_from: f64Source offset in seconds.
timeline_start: f64Composition timeline offset in seconds.
duration: Option<f64>Optional audible duration on the composition timeline.
volume: f64Linear gain in 0.0..=1.0.
playback_rate: f64Playback speed supported by FFmpeg atempo (0.5..=2.0).
looped: boolRepeat the source when it is shorter than the requested duration.
Implementations